/*+ Const.h
 *
 ******************************************************************************
 *
 *                        Trimble Navigation Limited
 *                           645 North Mary Avenue
 *                              P.O. Box 3642
 *                         Sunnyvale, CA 94088-3642
 *
 ******************************************************************************
 *
 *    Copyright  2005 Trimble Navigation Ltd.
 *    All Rights Reserved
 *
 ******************************************************************************
 *
 * Description:
 *    Constants and macros used by the application.
 *            
 * Revision History:
 *    09-22-2005    Mike Priven
 *                  Cleaned up and adapted for outside distribution.
 *
 *    xx-xx-2001    Sean Zhi
 *                  Original
 *
 * Notes:
 *
-*/

#ifndef CONST_H
#define CONST_H

// Version information
#define APP_NAME                "iQFlashLoader"
#define APP_VER_MAJOR           1
#define APP_VER_MINOR           1
#define APP_VER_MON             2
#define APP_VER_DAY             1
#define APP_VER_YEAR            2006

// Error codes for S-record file loader CUtil::LoadSrecFile() 
#define ERR_MEM_ALLOC           (-1)  // S-rec memory allocation failure
#define ERR_SREC_CHKSM          (-2)  // S-rec checksum incorrect
#define ERR_SREC_ADDR           (-3)  // S-rec address value invalid
#define ERR_SREC_BASE           (-4)  // S-rec base address/ROM type mismatch 
#define ERR_SREC_SIZE           (-5)  // S-rec file size mismatch
#define ERR_SREC_FORMAT         (-6)  // S-rec file format incorrect

// Serial port constants
#define NUM_PORTS               16 
#define ID_COMMCTRL_1           2001  // Ctrl ID for comm control
#define ID_COMMCTRL_2           2002  
#define ID_COMMCTRL_3           2003  
#define ID_COMMCTRL_4           2004  
#define ID_COMMCTRL_5           2005  
#define ID_COMMCTRL_6           2006  
#define ID_COMMCTRL_7           2007  
#define ID_COMMCTRL_8           2008  
#define ID_COMMCTRL_9           2009 
#define ID_COMMCTRL_10          2010 
#define ID_COMMCTRL_11          2011 
#define ID_COMMCTRL_12          2012 
#define ID_COMMCTRL_13          2013 
#define ID_COMMCTRL_14          2014 
#define ID_COMMCTRL_15          2015 
#define ID_COMMCTRL_16          2016 

// ROM file types
#define FW_ROM                  0
#define BOOT_ROM                1

// Misc constants
#define	LINE_SIZE               256
#define INVALID_ADDR            0xFFFFFFFF
#define PACKET_SIZE				0xE0
#define ROM_BUFFER_SIZE         0xA0000
#define DEMON_BUFFER_SIZE       0x3000


// Application states
enum 
{
    S_MON_INIT=0,
    S_MON_ENTRY_CMD_SENT,
    S_MON_ENTRY_CMD_ACK,
    S_MON_ENTRY_CMD_CMP,
    S_DEMON_CMD_SENT,
    S_DEMON_CMD_ACK,
    S_DEMON_CMD_CMP,
    S_ERASE_CMD_SENT,
    S_ERASE_CMD_ACK,
    S_FWLOAD_CMD_SENT,
    S_FWLOAD_CMD_ACK,
    S_FWLOAD_CMD_CMP,
};

// Default base addresses for boot code and firmware
#define	DEFAULT_FW_ADDR         "00C10000"

// Default option for wait for ACK
#define DEFAULT_NOWAIT_ACK      FALSE

// Demo start address
#define DEMON_START_ADDR        0x800

// Boot monitor protocol constants
#define	STX				        (unsigned char)0x02
#define	ETX				        (unsigned char)0x03
#define	NULL_C			        (unsigned char)0x00

#define	ACK				        (unsigned char)0x06
#define	NAK				        (unsigned char)0x15

#define	ENQ				        (unsigned char)0x05

#define	FW_ERASE_PKT_ID	        (unsigned char)0x8F
#define	RESTART_PKT_ID	        (unsigned char)0x8C
#define	RUNCODEAT_PKT_ID        (unsigned char)0x82
#define FLASH_PROGRAM_PKT_ID    (unsigned char)0x89
#define DOWNLOAD_DATA_PKT_ID    (unsigned char)0x81
#define BAUD_CONTROL_PKT_ID	 	(unsigned char)0x86

#endif // CONST_H
